@@ -1,24 +1,26 @@
 <?php
 
 function list_jumps() {
-	global $second_offset, $lang, $cal;
-	$today = date('Ymd', strtotime("now + $second_offset seconds"));
+	global $phpiCal_config, $lang, $cal;
+	$calName = join(',', array_map("getCalendarName", split(',', $cal)));
+	$today = date('Ymd', time() + $phpiCal_config->second_offset);
 	$return = '<option value="#">'.$lang['l_jump'].'</option>';
-	$return .= '<option value="day.php?cal='.$cal.'&amp;getdate='.$today.'">'.$lang['l_goday'].'</option>';
-	$return .= '<option value="week.php?cal='.$cal.'&amp;getdate='.$today.'">'.$lang['l_goweek'].'</option>';
-	$return .= '<option value="month.php?cal='.$cal.'&amp;getdate='.$today.'">'.$lang['l_gomonth'].'</option>';
-	$return .= '<option value="year.php?cal='.$cal.'&amp;getdate='.$today.'">'.$lang['l_goyear'].'</option>';
+	$return .= '<option value="day.php?cal='.$calName.'&amp;getdate='.$today.'">'.$lang['l_goday'].'</option>';
+	$return .= '<option value="week.php?cal='.$calName.'&amp;getdate='.$today.'">'.$lang['l_goweek'].'</option>';
+	$return .= '<option value="month.php?cal='.$calName.'&amp;getdate='.$today.'">'.$lang['l_gomonth'].'</option>';
+	$return .= '<option value="year.php?cal='.$calName.'&amp;getdate='.$today.'">'.$lang['l_goyear'].'</option>';
 	return $return;
 }
 
 function list_calcolors() {
-	global $template, $master_array, $unique_colors;
+	global $phpiCal_config, $master_array;
+	$return = '';
 	$i = 1;
 	if (is_array($master_array['-3'])) {
 		foreach ($master_array['-3'] as $key => $val) {
-			if ($i > $unique_colors) $i = 1;
+			if ($i > $phpiCal_config->unique_colors) $i = 1;
 			$val = str_replace ("\,", ",", $val);
-			$return .= '<img src="templates/'.$template.'/images/monthdot_'.$i.'.gif" alt="" /> '.$val.'<br />';
+			$return .= '<img src="templates/'.$phpiCal_config->template.'/images/monthdot_'.$i.'.gif" alt="" /> '.$val.'<br />';
 			$i++;
 		}
 	}
@@ -29,6 +31,7 @@ function list_months() {
 	global $getdate, $this_year, $cal, $dateFormat_month;
 	$month_time 	= strtotime("$this_year-01-01");
 	$getdate_month 	= date("m", strtotime($getdate));
+	$return = '';
 	for ($i=0; $i<12; $i++) {
 		$monthdate 		= date ("Ymd", $month_time);
 		$month_month 	= date("m", $month_time);
@@ -45,10 +48,11 @@ function list_months() {
 
 
 function list_years() {
-	global $getdate, $this_year, $cal, $num_years;
+	global $getdate, $this_year, $cal, $phpiCal_config;
 	$year_time = strtotime($getdate);
-	for ($i=0; $i < $num_years; $i++) {
-		$offset = $num_years - $i;
+	$return = '';
+	for ($i=0; $i < $phpiCal_config->num_years; $i++) {
+		$offset = $phpiCal_config->num_years - $i;
 		$prev_time = strtotime("-$offset year", $year_time);
 		$prev_date = date("Ymd", $prev_time);
 		$prev_year = date("Y", $prev_time);
@@ -59,7 +63,7 @@ function list_years() {
 	$getdate_year = date("Y", $year_time);
 	$return .= "<option value=\"year.php?cal=$cal&amp;getdate=$getdate_date\" selected=\"selected\">$getdate_year</option>\n";
 	
-	for ($i=0; $i < $num_years; $i++) {
+	for ($i=0; $i < $phpiCal_config->num_years; $i++) {
 		$offset = $i + 1;
 		$next_time = strtotime("+$offset year", $year_time);
 		$next_date = date("Ymd", $next_time);
@@ -72,14 +76,15 @@ function list_years() {
 
 
 function list_weeks() {
-	global $getdate, $this_year, $cal, $dateFormat_week_jump, $week_start_day;
+	global $getdate, $this_year, $cal, $dateFormat_week_jump, $phpiCal_config;
 	ereg ("([0-9]{4})([0-9]{2})([0-9]{2})", $getdate, $day_array2);
 	$this_day 			= $day_array2[3]; 
 	$this_month 		= $day_array2[2];
 	$this_year 			= $day_array2[1];
 	$check_week 		= strtotime($getdate);
-	$start_week_time 	= strtotime(dateOfWeek(date("Ymd", strtotime("$this_year-01-01")), $week_start_day));
+	$start_week_time 	= strtotime(dateOfWeek(date("Ymd", strtotime("$this_year-01-01")), $phpiCal_config->week_start_day));
 	$end_week_time 		= $start_week_time + (6 * 25 * 60 * 60);
+	$return = '';
 		
 	do {
 		$weekdate 		= date ("Ymd", $start_week_time);
@@ -100,6 +105,7 @@ function list_weeks() {
 
 function list_languages() {
 	global $getdate, $cal, $current_view;
+	$return = '';
 	$dir_handle = @opendir(BASE.'languages/');
 	$tmp_pref_language = urlencode(ucfirst($language));
 	while ($file = readdir($dir_handle)) {
