@@ -43,6 +43,7 @@ $lang['l_gomonth']			= 'Anar a aquest Mes';
 $lang['l_goyear']			= 'Anar a aquest Any';
 $lang['l_search']			= 'Buscar'; // the verb
 $lang['l_results']			= 'Resultats de la cerca';
+$lang['l_pick_multiple'] 	= 'Pick multiple';
 $lang['l_query']			= 'Consulta: '; // will be followed by the search query
 $lang['l_no_results']		= 'No s\'ha trobat cap event';
 $lang['l_goprint']			= 'Format d\'impressi&oacute;';
@@ -80,6 +81,9 @@ $lang['l_priority_low']		= 'Baixa';
 $lang['l_priority_medium']	= 'Mitjana';
 $lang['l_priority_none']	= 'Cap';
 $lang['l_status']			= 'Estat';
+$lang['l_status_confirmed'] = 'CONFIRMED' ; 
+$lang['l_status_cancelled'] = 'CANCELLED'; 
+$lang['l_status_tentative'] = 'TENTATIVE'; 
 $lang['l_todo']				= 'Pendent';
 $lang['l_unfinished']		= 'Sense acabar';
 $lang['l_prefs_set'] 		= 'Les teves prefer&egrave;ncies s\'han guardat.';
@@ -171,6 +175,7 @@ $dateFormat_week_list = '%a, %e de %b';
 $dateFormat_week_jump = '%e de %b';
 $dateFormat_month = '%B de %Y';
 $dateFormat_month_list = '%A, %e de %B';
+$dateFormat_year = '%Y';
 
 /*
 Notes about dateFormat_*
