@@ -43,6 +43,7 @@ $lang['l_gomonth'] 			= 'Vis denne m&aring;neden';
 $lang['l_goyear'] 			= 'Vis dette &aring;ret';
 $lang['l_search'] 			= 'S&oslash;k'; // the verb
 $lang['l_results'] 			= 'S&oslash;keresultater';
+$lang['l_pick_multiple'] 	= 'Pick multiple';
 $lang['l_query'] 			= 'Foresp&oslash;rsel: '; // will be followed by the search query
 $lang['l_no_results'] 		= 'Ingen hendelser';
 $lang['l_goprint'] 			= 'Utskriftsvennlig';
@@ -80,6 +81,9 @@ $lang['l_priority_low']		= 'Lav';
 $lang['l_priority_medium']	= 'Medium';
 $lang['l_priority_none']	= 'Ingen';
 $lang['l_status']			= 'Status';
+$lang['l_status_confirmed'] = 'CONFIRMED' ; 
+$lang['l_status_cancelled'] = 'CANCELLED'; 
+$lang['l_status_tentative'] = 'TENTATIVE'; 
 $lang['l_todo']				= 'Oppgaver';
 $lang['l_unfinished']		= 'Uferdig';
 $lang['l_prefs_set'] 		= 'Valgene dine har blitt lagret.';
@@ -173,6 +177,7 @@ $dateFormat_week_list = '%a %e. %b';
 $dateFormat_week_jump = '%b %e';
 $dateFormat_month = '%B %Y';
 $dateFormat_month_list = '%A %e. %B';
+$dateFormat_year = '%Y';
 
 /*
 Notes about dateFormat_*
